@@ -27,9 +27,9 @@ SOFTWARE.
 """
 DESCRIPTION
 
-Just a file to be able to use retinal_implants_utils as a module and import it.
+Just a file to be able to use pytorchUtils as a module and import it.
 """
 
-from .Pipeline    import Pipeline
-from .LiveFigure  import LiveFigure
-from .ResNet18MNIST import ResNet18MNIST
\ No newline at end of file
+from .Pipeline   import Pipeline
+from .LiveFigure import LiveFigure
+from  .models import *
\ No newline at end of file
